package sun.util.locale.provider;

import java.util.spi.LocaleServiceProvider;
import java.util.Map;
import java.util.spi.CalendarNameProvider;
import java.util.spi.CalendarDataProvider;
import java.util.Locale;

public class CalendarDataUtility
{
    public static final String FIRST_DAY_OF_WEEK = "firstDayOfWeek";
    public static final String MINIMAL_DAYS_IN_FIRST_WEEK = "minimalDaysInFirstWeek";
    
    private CalendarDataUtility() {
    }
    
    public static int retrieveFirstDayOfWeek(Locale locale) {
        Integer n = (Integer)LocaleServiceProviderPool.getPool(CalendarDataProvider.class).getLocalizedObject(CalendarDataUtility.CalendarWeekParameterGetter.INSTANCE, locale, "firstDayOfWeek", new Object[0]);
        return (n != null && (int)n >= 1 && (int)n <= 7) ? ((int)n) : 1;
    }
    
    public static int retrieveMinimalDaysInFirstWeek(Locale locale) {
        Integer n = (Integer)LocaleServiceProviderPool.getPool(CalendarDataProvider.class).getLocalizedObject(CalendarDataUtility.CalendarWeekParameterGetter.INSTANCE, locale, "minimalDaysInFirstWeek", new Object[0]);
        return (n != null && (int)n >= 1 && (int)n <= 7) ? ((int)n) : 1;
    }
    
    public static String retrieveFieldValueName(String s, int i, int j, int k, Locale locale) {
        return (String)LocaleServiceProviderPool.getPool(CalendarNameProvider.class).getLocalizedObject(CalendarDataUtility.CalendarFieldValueNameGetter.INSTANCE, locale, normalizeCalendarType(s), new Object[] { Integer.valueOf(i), Integer.valueOf(j), Integer.valueOf(k), Boolean.valueOf(false) });
    }
    
    public static String retrieveJavaTimeFieldValueName(String s, int n, int n2, int n3, Locale locale) {
        LocaleServiceProviderPool pool = LocaleServiceProviderPool.getPool(CalendarNameProvider.class);
        String s2 = (String)pool.getLocalizedObject(CalendarDataUtility.CalendarFieldValueNameGetter.INSTANCE, locale, normalizeCalendarType(s), new Object[] { Integer.valueOf(n), Integer.valueOf(n2), Integer.valueOf(n3), Boolean.valueOf(true) });
        if (s2 == null) {
            s2 = (String)pool.getLocalizedObject(CalendarDataUtility.CalendarFieldValueNameGetter.INSTANCE, locale, normalizeCalendarType(s), new Object[] { Integer.valueOf(n), Integer.valueOf(n2), Integer.valueOf(n3), Boolean.valueOf(false) });
            return s2;
        }
        return s2;
    }
    
    public static Map<String, Integer> retrieveFieldValueNames(String s, int i, int j, Locale locale) {
        return (Map)LocaleServiceProviderPool.getPool(CalendarNameProvider.class).getLocalizedObject(CalendarDataUtility.CalendarFieldValueNamesMapGetter.INSTANCE, locale, normalizeCalendarType(s), new Object[] { Integer.valueOf(i), Integer.valueOf(j), Boolean.valueOf(false) });
    }
    
    public static Map<String, Integer> retrieveJavaTimeFieldValueNames(String s, int n, int n2, Locale locale) {
        LocaleServiceProviderPool pool = LocaleServiceProviderPool.getPool(CalendarNameProvider.class);
        Map<Object, Object> map = (Map)pool.getLocalizedObject(CalendarDataUtility.CalendarFieldValueNamesMapGetter.INSTANCE, locale, normalizeCalendarType(s), new Object[] { Integer.valueOf(n), Integer.valueOf(n2), Boolean.valueOf(true) });
        if (map == null) {
            map = (Map)pool.getLocalizedObject(CalendarDataUtility.CalendarFieldValueNamesMapGetter.INSTANCE, locale, normalizeCalendarType(s), new Object[] { Integer.valueOf(n), Integer.valueOf(n2), Boolean.valueOf(false) });
            return map;
        }
        return map;
    }
    
    static String normalizeCalendarType(String s) {
        String s2;
        if (s.equals("gregorian") || s.equals("iso8601")) {
            s2 = "gregory";
        }
        else if (s.startsWith("islamic")) {
            s2 = "islamic";
        }
        else {
            s2 = s;
        }
        return s2;
    }
    
    private static class CalendarFieldValueNameGetter implements LocaleServiceProviderPool.LocalizedObjectGetter<CalendarNameProvider, String>
    {
        private static final CalendarDataUtility.CalendarFieldValueNameGetter INSTANCE;
        
        @Override
        public String getObject(CalendarNameProvider calendarNameProvider, Locale locale, String s, Object... array) {
            assert array.length == 4;
            int intValue = (int)array[0];
            int intValue2 = (int)array[1];
            int intValue3 = (int)array[2];
            if ((boolean)array[3] && calendarNameProvider instanceof CalendarNameProviderImpl) {
                return ((CalendarNameProviderImpl)calendarNameProvider).getJavaTimeDisplayName(s, intValue, intValue2, intValue3, locale);
            }
            return calendarNameProvider.getDisplayName(s, intValue, intValue2, intValue3, locale);
        }
        
        static {
            INSTANCE = new CalendarDataUtility.CalendarFieldValueNameGetter();
        }
    }
    
    private static class CalendarFieldValueNamesMapGetter implements LocaleServiceProviderPool.LocalizedObjectGetter<CalendarNameProvider, Map<String, Integer>>
    {
        private static final CalendarDataUtility.CalendarFieldValueNamesMapGetter INSTANCE;
        
        @Override
        public Map<String, Integer> getObject(CalendarNameProvider calendarNameProvider, Locale locale, String s, Object... array) {
            assert array.length == 3;
            int intValue = (int)array[0];
            int intValue2 = (int)array[1];
            if ((boolean)array[2] && calendarNameProvider instanceof CalendarNameProviderImpl) {
                return ((CalendarNameProviderImpl)calendarNameProvider).getJavaTimeDisplayNames(s, intValue, intValue2, locale);
            }
            return calendarNameProvider.getDisplayNames(s, intValue, intValue2, locale);
        }
        
        static {
            INSTANCE = new CalendarDataUtility.CalendarFieldValueNamesMapGetter();
        }
    }
    
    private static class CalendarWeekParameterGetter implements LocaleServiceProviderPool.LocalizedObjectGetter<CalendarDataProvider, Integer>
    {
        private static final CalendarDataUtility.CalendarWeekParameterGetter INSTANCE;
        
        @Override
        public Integer getObject(CalendarDataProvider calendarDataProvider, Locale locale, String str, Object... array) {
            assert array.length == 0;
            int n = -1;
            switch (str.hashCode()) {
                case 522320983: {
                    if (str.equals("firstDayOfWeek")) {
                        n = 0;
                        break;
                    }
                    break;
                }
                case 1347492455: {
                    if (str.equals("minimalDaysInFirstWeek")) {
                        n = 1;
                        break;
                    }
                    break;
                }
            }
            int i;
            switch (n) {
                case 0: {
                    i = calendarDataProvider.getFirstDayOfWeek(locale);
                    break;
                }
                case 1: {
                    i = calendarDataProvider.getMinimalDaysInFirstWeek(locale);
                    break;
                }
                default: {
                    throw new InternalError("invalid requestID: " + str);
                }
            }
            return (i != 0) ? Integer.valueOf(i) : null;
        }
        
        static {
            INSTANCE = new CalendarDataUtility.CalendarWeekParameterGetter();
        }
    }
}
